# Histographer Analysis
Package for image analysis as used in [Histographer's](https://github.com/histographer) packages.

## Requirements
`histographer-analysis` is confirmed to work with Python >= 3.6.

## Installation
The package can be installed using `pip`.
```sh
python -m pip install histographer-analysis
```
